<?php # $Id: lang_bg.inc.php 1740 2007-06-28 06:20:44Z jwalker $

 /**
 *  @version $Revision: 1740 $
 *  @author Ivan Cenov jwalker@hotmail.bg
 */

    @define('PLUGIN_RECENTENTRIES_TITLE', ' ');
    @define('PLUGIN_RECENTENTRIES_BLAHBLAH', '      ');
    @define('PLUGIN_RECENTENTRIES_NUMBER', '  ');
    @define('PLUGIN_RECENTENTRIES_NUMBER_BLAHBLAH', '  ,     ( : 10)');
    @define('PLUGIN_RECENTENTRIES_NUMBER_FROM', '      ');
    @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_DESC', '  ,          . ( :  ' . $serendipity['fetchLimit'] . '   )');
    @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_ALL', ' ');
    @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_RECENT', '    ');
    @define('PLUGIN_RECENTENTRIES_RANDOMIZE', '   ');
    @define('PLUGIN_RECENTENTRIES_RANDOMIZE_DESC', '  ,    .');
